@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Cxn::AEHTTP;
-$Search::Elasticsearch::Cxn::AEHTTP::VERSION = '1.18';
+$Search::Elasticsearch::Cxn::AEHTTP::VERSION = '1.19';
 use AnyEvent::HTTP qw(http_request);
 use Promises qw(deferred);
 use Try::Tiny;
@@ -72,9 +72,10 @@ sub error_from_text {
 #===================================
     local $_ = $_[2];
     return
-          /[Tt]imed out/     ? 'Timeout'
-        : /Invalid argument/ ? 'Cxn'
-        :                      'Request';
+          /[Tt]imed out/              ? 'Timeout'
+        : /certificate verify failed/ ? 'SSL'
+        : /Invalid argument/          ? 'Cxn'
+        :                               'Request';
 }
 
 1;
@@ -93,7 +94,7 @@ Search::Elasticsearch::Cxn::AEHTTP - An async Cxn implementation which uses AnyE
 
 =head1 VERSION
 
-version 1.18
+version 1.19
 
 =head1 DESCRIPTION
 
@@ -165,6 +166,9 @@ attacks, you could do the following:
         }
     );
 
+If the remote server cannot be verified, an
+L<Search::Elasticsearch::Error|SSL error> will be thrown.
+
 If you want your client to present its own certificate to the remote
 server, then use:
 
