@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Cxn::Mojo;
-$Search::Elasticsearch::Cxn::Mojo::VERSION = '1.18';
+$Search::Elasticsearch::Cxn::Mojo::VERSION = '1.19';
 use Mojo::UserAgent();
 use Promises qw(deferred);
 use Try::Tiny;
@@ -73,9 +73,10 @@ sub error_from_text {
 #===================================
     local $_ = $_[2];
     return
-          /[Tt]imed out/     ? 'Timeout'
-        : /Invalid argument/ ? 'Cxn'
-        :                      'Request';
+          /[Tt]imed out/               ? 'Timeout'
+        : /SSL connect attempt failed/ ? 'SSL'
+        : /Invalid argument/           ? 'Cxn'
+        :                                'Request';
 }
 
 #===================================
@@ -104,7 +105,7 @@ Search::Elasticsearch::Cxn::Mojo - An async Cxn implementation which uses Mojo::
 
 =head1 VERSION
 
-version 1.18
+version 1.19
 
 =head1 DESCRIPTION
 
@@ -180,6 +181,9 @@ attacks, you could do the following:
         }
     );
 
+If the remote server cannot be verified, an
+L<Search::Elasticsearch::Error|SSL error> will be thrown.
+
 If you want your client to present its own certificate to the remote
 server, then use:
 
